"""
backend_statistic_chart automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_statistic_chart_data import BackendStatisticChartData
@dataclass_json
@dataclass
class BackendStatisticChart:
    labels: List[str]
    data: List[BackendStatisticChartData]
    series: List[str]
