"""
consumer_user_password_reset automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerUserPasswordReset:
    token: str
    new_password: str
