"""
consumer_grant automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from consumer_app import ConsumerApp
@dataclass_json
@dataclass
class ConsumerGrant:
    id: int
    app: ConsumerApp
    create_date: datetime.datetime
