"""
backend_generator_index_provider automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendGeneratorIndexProvider:
    name: str
    _class: str
