"""
consumer_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class ConsumerApp:
    id: int
    user_id: int
    status: int
    name: str
    url: str
    app_key: str
    app_secret: str
    date: str
    scopes: List[str]
    metadata: CommonMetadata
