"""
backend_sdk_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_sdk_types import BackendSdkTypes
@dataclass_json
@dataclass
class BackendSdkResponse:
    types: BackendSdkTypes
