"""
SystemTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from system_connection_tag import SystemConnectionTag
from system_meta_tag import SystemMetaTag
from system_payment_tag import SystemPaymentTag

class SystemTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass

    def payment(self) -> SystemPaymentTag:
        return SystemPaymentTag(
            this.http_client,
            this.parser
        )
    pass

    def meta(self) -> SystemMetaTag:
        return SystemMetaTag(
            this.http_client,
            this.parser
        )
    pass

    def connection(self) -> SystemConnectionTag:
        return SystemConnectionTag(
            this.http_client,
            this.parser
        )
    pass


