"""
backend_webhook automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_webhook_response import BackendWebhookResponse
@dataclass_json
@dataclass
class BackendWebhook:
    id: int
    event_id: int
    user_id: int
    name: str
    endpoint: str
    responses: List[BackendWebhookResponse]
