"""
system_route automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from system_route_path import SystemRoutePath
@dataclass_json
@dataclass
class SystemRoute:
    routes: SystemRoutePath
