"""
backend_plan automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendPlan:
    id: int
    name: str
    description: str
    price: float
    points: int
    period: int
    external_id: str
    scopes: List[str]
    metadata: CommonMetadata
