"""
CommonMessageException automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import sdkgen

class CommonMessageException(sdkgen.KnownStatusCodeException) {

    def __init__(self, payload: CommonMessage):
        self.payload = payload
    pass

}
