"""
backend_marketplace_collection_apps automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import Dict
from backend_marketplace_remote_app import BackendMarketplaceRemoteApp
class BackendMarketplaceCollectionApps(Dict[str, BackendMarketplaceRemoteApp]):
    pass
