"""
backend_dashboard_users automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from common_collection import CommonCollection
from backend_dashboard_user import BackendDashboardUser
@dataclass_json
@dataclass
class BackendDashboardUsers(CommonCollection[BackendDashboardUser]):
    pass
