"""
backend_generator_index_providers automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_generator_index_provider import BackendGeneratorIndexProvider
@dataclass_json
@dataclass
class BackendGeneratorIndexProviders:
    providers: List[BackendGeneratorIndexProvider]
