"""
backend_marketplace_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_marketplace_collection_apps import BackendMarketplaceCollectionApps
@dataclass_json
@dataclass
class BackendMarketplaceCollection:
    apps: BackendMarketplaceCollectionApps
