"""
backend_operation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_operation_parameters import BackendOperationParameters
from backend_operation_throws import BackendOperationThrows
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendOperation:
    id: int
    status: int
    active: bool
    public: bool
    stability: int
    description: str
    http_method: str
    http_path: str
    http_code: int
    name: str
    parameters: BackendOperationParameters
    incoming: str
    outgoing: str
    throws: BackendOperationThrows
    action: str
    costs: int
    scopes: List[str]
    metadata: CommonMetadata
