"""
ConsumerTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from consumer_account_tag import ConsumerAccountTag
from consumer_app_tag import ConsumerAppTag
from consumer_event_tag import ConsumerEventTag
from consumer_grant_tag import ConsumerGrantTag
from consumer_identity_tag import ConsumerIdentityTag
from consumer_log_tag import ConsumerLogTag
from consumer_page_tag import ConsumerPageTag
from consumer_payment_tag import ConsumerPaymentTag
from consumer_plan_tag import ConsumerPlanTag
from consumer_scope_tag import ConsumerScopeTag
from consumer_token_tag import ConsumerTokenTag
from consumer_transaction_tag import ConsumerTransactionTag
from consumer_webhook_tag import ConsumerWebhookTag

class ConsumerTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass

    def identity(self) -> ConsumerIdentityTag:
        return ConsumerIdentityTag(
            this.http_client,
            this.parser
        )
    pass

    def account(self) -> ConsumerAccountTag:
        return ConsumerAccountTag(
            this.http_client,
            this.parser
        )
    pass

    def transaction(self) -> ConsumerTransactionTag:
        return ConsumerTransactionTag(
            this.http_client,
            this.parser
        )
    pass

    def webhook(self) -> ConsumerWebhookTag:
        return ConsumerWebhookTag(
            this.http_client,
            this.parser
        )
    pass

    def token(self) -> ConsumerTokenTag:
        return ConsumerTokenTag(
            this.http_client,
            this.parser
        )
    pass

    def scope(self) -> ConsumerScopeTag:
        return ConsumerScopeTag(
            this.http_client,
            this.parser
        )
    pass

    def plan(self) -> ConsumerPlanTag:
        return ConsumerPlanTag(
            this.http_client,
            this.parser
        )
    pass

    def payment(self) -> ConsumerPaymentTag:
        return ConsumerPaymentTag(
            this.http_client,
            this.parser
        )
    pass

    def page(self) -> ConsumerPageTag:
        return ConsumerPageTag(
            this.http_client,
            this.parser
        )
    pass

    def log(self) -> ConsumerLogTag:
        return ConsumerLogTag(
            this.http_client,
            this.parser
        )
    pass

    def grant(self) -> ConsumerGrantTag:
        return ConsumerGrantTag(
            this.http_client,
            this.parser
        )
    pass

    def event(self) -> ConsumerEventTag:
        return ConsumerEventTag(
            this.http_client,
            this.parser
        )
    pass

    def app(self) -> ConsumerAppTag:
        return ConsumerAppTag(
            this.http_client,
            this.parser
        )
    pass


