"""
backend_action_execute_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_action_execute_response_headers import BackendActionExecuteResponseHeaders
from backend_action_execute_response_body import BackendActionExecuteResponseBody
@dataclass_json
@dataclass
class BackendActionExecuteResponse:
    status_code: int
    headers: BackendActionExecuteResponseHeaders
    body: BackendActionExecuteResponseBody
