"""
common_form_element automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class CommonFormElement:
    element: str
    name: str
    title: str
    help: str
