"""
consumer_log automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerLog:
    id: int
    app_id: int
    ip: str
    user_agent: str
    method: str
    path: str
    header: str
    body: str
    date: datetime.datetime
