"""
common_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
@dataclass_json
@dataclass
class CommonCollection:
    total_results: int
    start_index: int
    items_per_page: int
    entry: List[T]
