"""
backend_action_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_action_index_entry import BackendActionIndexEntry
@dataclass_json
@dataclass
class BackendActionIndex:
    actions: List[BackendActionIndexEntry]
