"""
backend_webhook_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendWebhookResponse:
    id: int
    status: int
    code: int
    attempts: int
    error: str
    execute_date: datetime.datetime
