"""
system_schema_form automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import Any
from typing import Dict
class SystemSchemaForm(Dict[str, Any]):
    pass
