"""
backend_identity_create automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_identity import BackendIdentity
@dataclass_json
@dataclass
class BackendIdentityCreate(BackendIdentity):
