"""
backend_scope_category_scope automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendScopeCategoryScope:
    id: int
    name: str
    description: str
