"""
backend_rate_allocation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendRateAllocation:
    id: int
    operation_id: int
    user_id: int
    plan_id: int
    app_id: int
    authenticated: bool
