"""
backend_generator_provider automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_generator_provider_config import BackendGeneratorProviderConfig
@dataclass_json
@dataclass
class BackendGeneratorProvider:
    path: str
    scopes: List[str]
    public: bool
    config: BackendGeneratorProviderConfig
