"""
consumer_token_create automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
@dataclass_json
@dataclass
class ConsumerTokenCreate:
    name: str
    scope: List[str]
    expire: datetime.datetime
