"""
consumer_authorize_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from consumer_authorize_response_token import ConsumerAuthorizeResponseToken
@dataclass_json
@dataclass
class ConsumerAuthorizeResponse:
    type: str
    token: ConsumerAuthorizeResponseToken
    code: str
    redirect_uri: str
