"""
backend_page_update automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_page import BackendPage
@dataclass_json
@dataclass
class BackendPageUpdate(BackendPage):
