"""
consumer_authorize_meta automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from consumer_scope import ConsumerScope
@dataclass_json
@dataclass
class ConsumerAuthorizeMeta:
    name: str
    url: str
    scopes: List[ConsumerScope]
