"""
backend_dashboard_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendDashboardRequest:
    id: int
    path: str
    ip: str
    date: datetime.datetime
