"""
consumer_page_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from common_collection import CommonCollection
from consumer_page import ConsumerPage
@dataclass_json
@dataclass
class ConsumerPageCollection(CommonCollection[ConsumerPage]):
    pass
