"""
system_route_path automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import Dict
from system_route_method import SystemRouteMethod
class SystemRoutePath(Dict[str, SystemRouteMethod]):
    pass
