"""
backend_action_execute_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_action_execute_request_body import BackendActionExecuteRequestBody
@dataclass_json
@dataclass
class BackendActionExecuteRequest:
    method: str
    uri_fragments: str
    parameters: str
    headers: str
    body: BackendActionExecuteRequestBody
