"""
backend_dashboard_transaction automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendDashboardTransaction:
    id: int
    status: str
    provider: str
    transaction_id: str
    amount: float
    date: datetime.datetime
