"""
backend_identity automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_identity_config import BackendIdentityConfig
@dataclass_json
@dataclass
class BackendIdentity:
    id: int
    app_id: int
    role_id: int
    name: str
    icon: str
    _class: str
    config: BackendIdentityConfig
    allow_create: bool
