"""
system_route_method automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import Dict
class SystemRouteMethod(Dict[str, str]):
    pass
