"""
consumer_authorize_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerAuthorizeRequest:
    response_type: str
    client_id: str
    redirect_uri: str
    scope: str
    state: str
    allow: bool
