"""
backend_action automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_action_config import BackendActionConfig
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendAction:
    id: int
    status: int
    name: str
    _class: str
    async: bool
    config: BackendActionConfig
    metadata: CommonMetadata
