"""
backend_connection_introspection_entity automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_connection_introspection_entity_row import BackendConnectionIntrospectionEntityRow
@dataclass_json
@dataclass
class BackendConnectionIntrospectionEntity:
    name: str
    headers: List[str]
    rows: List[BackendConnectionIntrospectionEntityRow]
