"""
common_form_element_text_area automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from common_form_element import CommonFormElement
@dataclass_json
@dataclass
class CommonFormElementTextArea(CommonFormElement):
    mode: str
