"""
backend_rate automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_rate_allocation import BackendRateAllocation
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendRate:
    id: int
    priority: int
    name: str
    rate_limit: int
    timespan: datetime.timedelta
    allocation: List[BackendRateAllocation]
    metadata: CommonMetadata
