"""
consumer_token automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
@dataclass_json
@dataclass
class ConsumerToken:
    id: int
    status: int
    name: str
    scopes: List[str]
    ip: str
    expire: datetime.datetime
    date: datetime.datetime
