"""
backend_marketplace_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendMarketplaceApp:
    version: str
    description: str
    screenshot: str
    website: str
    download_url: str
    sha_hash: str
    start_url: str
