"""
backend_operation_parameters automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import Dict
from backend_operation_schema import BackendOperationSchema
class BackendOperationParameters(Dict[str, BackendOperationSchema]):
    pass
