"""
consumer_user_register automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerUserRegister:
    name: str
    email: str
    password: str
    captcha: str
