"""
consumer_token_access_token automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerTokenAccessToken:
    access_token: str
    token_type: str
    expires_in: int
    refresh_token: str
    scope: str
