"""
system_about automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from system_about_apps import SystemAboutApps
from system_about_link import SystemAboutLink
@dataclass_json
@dataclass
class SystemAbout:
    api_version: str
    title: str
    description: str
    terms_of_service: str
    contact_name: str
    contact_url: str
    contact_email: str
    license_name: str
    license_url: str
    payment_currency: str
    categories: List[str]
    scopes: List[str]
    apps: SystemAboutApps
    links: List[SystemAboutLink]
